@@ -1,11 +1,35 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    4  #  com.apple.cs.CodeSignature              t   4                     Ajulia-config A427R7F42H L
-0t<                    J*;%-<#                   H    ,            
+    Mac OS X            	   2  *o     *                                      ATTR      *  L  )U                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Ajulia-config A427R7F42H !R3~v1                                        L
+0t<                    J*;%-<# qq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                  H    ,            
 com.apple.env                      julia-config                  
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      Ajulia-config A427R7F42H |ZЂx\lLV~cpKY7,C0                                g]Fq`u.E\&F)Y'	0	*H
+A427R7F42H               4                      Ajulia-config A427R7F42H ONvHl_Zt+5b4UEhY2                                                                |ZЂx\lLV~cpKY7,C0                                g]Fq`u.E\&F)Y'	0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -83,47 +107,50 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251215123659Z0/	*H
-	1" ^|7eFoոˁw1ϖ&ۥNGخ0[	*Hcd	1N0+x^!j,-0-	`He 
-+ǵ)RE ލ.(.,]`$70[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260106194149Z0/	*H
+	1" R=^MaX3 R#9Pb\3<0[	*Hcd	1N0+Lyb5'֤ %0-	`He U>`O:gr_pVxTp!0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		wnhe8dXLIWqeLJ3d0i3JA+wVwPc=
+		2Ex5YqvS8zX9urSNJ7G7oNakICU=
 		</data>
 		<data>
-		DSvHtSlSEc9FHyDc+t6NLsfb4Qs=
+		/f5V8z5gDE8aOmdyBp5fn72D9HA=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  /7K6sx~puekK]Q|G"oQ&Uy[muggkSH>3,KDeu[
-+!"eڏ#V<E'"釥9WB󘓳ǟc7BqsmםD僜FHg%˙%buآÜXD z RfXD(Șepe6o	p7̡0*H
+  Jx$`d{ \pY'u0]wLS(r$Xp9:y<C܍$d [ג}0f5:m̠٣{	!-A"zX	fǬz0Y_I2W41|['MFta^TL)sH1T"[
+^?lhz;d-hp>SgSc Nhf)p-oJApfϕ0*H
 	10	*H
-010	+ 0{*H
-	lj0h*010
-	`He  Xss̋!ȵ`$p|uтy20251215123700Z0	 S.q$
-00:0
+010	+ 0z*H
+	ki0g*010
+	`He  45u
+O.	߷(}8n(eVwG:R|K*Ԇ20260106194150Z0WA!Z_
+00{E0Q;0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-251208174023Z
-260119174022Z0A10UTimestamp Signer MA210U
+260105174054Z
+260216174053Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- PT3HʦY$)4 ꩦ鈤0W ؠ#H4	'Te1sWx.'F%te$L3H}lMUהia$;1kGt_Q3%2YPQ8Qy6\cr<j(O)Wr#0:(2l<Hky$0m_Zm,脥FQiiP˲1ءAT6a W55	I# 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uvq!	#ğ=80U0
+ t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
+PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
+ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
 	*H
-  }T[ipT!5]]M+P;"͛*q^}w`"8@I1~StV q=NAp-N¼!~v<Uu=狖U~RZ<ڌXGI΄O_#$V*Ar49֐A{=\ݳӏ<,JY)uC(xq0hYg`A]\"Bbeq
-ldʪiG^SI-/C^A~J00}LWc0
+  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
+>G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
+މASVO@C]>{6%@nm|?A"00}LWc0
 	*H
  0b10	UUS10U
 
@@ -164,17 +191,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS:0	+ 0	*H
+Apple Inc.10	UUS{E0Q;0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251215123700Z0#	*H
-	1l')
-V.Ō:0+*H
-	1000Ӟw!\ _0
+260106194150Z0#	*H
+	1~Jǩq0+*H
+	10004,yz9_0
 	*H
-  (:ya^vHjSliVlGzז~鞴6&p="Ge^P
-%\XNNzYV&WіwD/l%)wk:G^Þ>zt3A6mOoMTWG
-USn1؄IΒ0Sy4*A@c#>U!ꬦi9j
-@OӐfiV|	 #l_3HA      
\ No newline at end of file
+  Z eTEz){3{jШϳQ
++gԝŊGQQ uHo<)g/A]-=Nv/Q$GoFFQi}ig(85\=l@xEZj {Qp;{1}3־	l[GoKh-:s|oʋw){:^`u\`x{7qm2uL      
\ No newline at end of file
