@@ -1,9 +1,33 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-buildscript A427R7F42H ~ BQoPG}G>                    XcCp0@Js5IN                            juliac-buildscript                    
+    Mac OS X            	   2  *P     *                                      ATTR      *  L  )6                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      	     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Gjuliac-buildscript A427R7F42H !R3~v1                                        ~ BQoPG}G>                    XcCp0@Js5INqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                            juliac-buildscript                    
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      Gjuliac-buildscript A427R7F42H +R( 7#u9JPi                                B'G\,vke1wŬ6haq
+A427R7F42H               4                      Gjuliac-buildscript A427R7F42H ONvHl_Zt+5b4UEhY2                                                                +R( 7#u9JPi                                B'G\,vke1wŬ6haq
 by-\J0	*H
 010
 	`He 0	*H
@@ -82,48 +106,53 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251215123700Z0/	*H
-	1" ){AL
-/x39?Æp0[	*Hcd	1N0+2?S#?
-v0-	`He  [zy9P:w
--ZpU40[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260106194149Z0/	*H
+	1" ݷ)ΰ~:yXԢK.x<60[	*Hcd	1N0+S=SM_Nl0-	`He 9+A;)o/Ge)sqAQ0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		lhrS5wwyP7FTIx7BPxjf5w33GHY=
+		Uz1TlQKpw/3HTbML2RjuG19ObOU=
 		</data>
 		<data>
-		nSDeDFt6eec5mgHYUBoHp4866Xc=
+		Gzmx4K/E9SsSQfbAOylvL0dlKXM=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  ';3=(*:UzzDvFN$Tf0*eh_7zyNFI0W5_|sSkԪSp`~wx&hXKxW~o{Ī]_"hK8rB1Wodl3R]['Z"I"t닋J	Vo2D>?щQxak5ҡV1"2A2(Iͦ#^r<êtwP"S^	&x/0*H
+  76]! t\9z$^ae-_1uzM ;5 |\Pd.Tԏ՘8
+K>;{m+;_o\u)ؗ]T*~aa蜘49Z _)s>͒>'f4q{MxL(8-A,Ǧ^.q5zZ'
+y \&Z	6
+5%]Qj߳Z2&i_Ba
+\A0*H
 	10	*H
-010	+ 0z*H
-	ki0g*010
-	`He  %:^dsPR +?o68 7qY20251215123700Z0t_X^l5f
-00:0
+010	+ 0{*H
+	lj0h*010
+	`He  U]܏&S	KrL
+&}hV<20260106194149Z0	 ]젂
+00{E0Q;0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-251208174023Z
-260119174022Z0A10UTimestamp Signer MA210U
+260105174054Z
+260216174053Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- PT3HʦY$)4 ꩦ鈤0W ؠ#H4	'Te1sWx.'F%te$L3H}lMUהia$;1kGt_Q3%2YPQ8Qy6\cr<j(O)Wr#0:(2l<Hky$0m_Zm,脥FQiiP˲1ءAT6a W55	I# 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uvq!	#ğ=80U0
+ t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
+PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
+ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
 	*H
-  }T[ipT!5]]M+P;"͛*q^}w`"8@I1~StV q=NAp-N¼!~v<Uu=狖U~RZ<ڌXGI΄O_#$V*Ar49֐A{=\ݳӏ<,JY)uC(xq0hYg`A]\"Bbeq
-ldʪiG^SI-/C^A~J00}LWc0
+  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
+>G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
+މASVO@C]>{6%@nm|?A"00}LWc0
 	*H
  0b10	UUS10U
 
@@ -164,14 +193,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS:0	+ 0	*H
+Apple Inc.10	UUS{E0Q;0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251215123700Z0#	*H
-	1(h	9N/Q0+*H
-	1000Ӟw!\ _0
+260106194149Z0#	*H
+	1ixI[EG\nD0+*H
+	10004,yz9_0
 	*H
-  fx&҅tqZF^r?|,BjC;,UT5=.]
-^+Yq^6DE,0})(8U !2\?Ĕm o6KkA)ɰiΔ(7hKNڴH&8lx|+L.i)K#&C3_tnR{VMn9s?I_<5"ށ8;nc)CőV#s      
\ No newline at end of file
+  HӦaE|<
+Sf9gFq枔-~'_h7\.GIf>J1>I3Itjs蛰eq9[i(#I0G@Y'AӧѧA!k3.DUظa0H;U.4)3*dͼ5Ӭ '+Ic=)o۪*&0,Hˡ@R./L0CŁ      
\ No newline at end of file
