@@ -1,9 +1,33 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      \      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              x   4        ,             Ejuliac-trim-base A427R7F42H 3@'\\;̗                    Hzo ضrCI                            juliac-trim-base                  
+    Mac OS X            	   2  *G     *y                                      ATTR      *y  L  )-                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements           com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4        ,             Ejuliac-trim-base A427R7F42H !R3~v1                                        3@'\\;̗                    Hzo ضrCIqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                            juliac-trim-base                  
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4        ,              Ejuliac-trim-base A427R7F42H Ƶ
+A427R7F42H               4        ,              Ejuliac-trim-base A427R7F42H ONvHl_Zt+5b4UEhY2                                                                Ƶ
 :aI=mކ3 Ug]
 /                                77+9n)]i'PYZ]0	*H
 010
@@ -83,48 +107,53 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251215123700Z0/	*H
-	1" N`̚Vhq&&Bz?}
-0[	*Hcd	1N0+/ ,UH[]롱0-	`He S)LgZ??j׳A7?i0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260106194149Z0/	*H
+	1" xIO8`0*H ZGd[F0[	*Hcd	1N0+V@(~;+$ZЈ0-	`He <Zb9x8y;Zw3n0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		oy8gqyxVC5bqi/tIW3+DXeuhsfs=
+		VkDb8ih+Av4UO4+pKySoWsnQiNk=
 		</data>
 		<data>
-		Uym8tkxnvFqYFD/azD+5atezQbA=
+		BjxaiGI5eBH3+g/1s+I4eTv5xFo=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  NpjV+8 \pZWB hOh)ephTI+/i,H6P1Ź]W/XVOnY.x*B$˫5W5M%BT;au)IKȂ mwqdDaT)O!
-2z,gdXv;H0ub*l,/$2Q |['yˀN
-0*H
+  L0I'է' 5w7jqF=0uSZn~<AU
+I<6Rm+,ûKG(AWܓ<
+~Jx2_{SG*q+c'oX.F;RNp٨DP@.Z_MɧӁIux%-UF%eKӋD4DCତNi\}xa<&[6H~mfĜx"-ey9GJ?0*H
 	10	*H
-010	+ 0{*H
-	lj0h*010
-	`He  #&Mxd3g~ǨSYWnh@i20251215123701Z0	 h蠂
-00:0
+010	+ 0z*H
+	ki0g*010
+	`He  Vq/y챥5:_N՞`FYYz
+20260106194149Z0zY4	s)
+00;^0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-251208174023Z
-260119174022Z0A10UTimestamp Signer MA210U
+260105174054Z
+260216174053Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- PT3HʦY$)4 ꩦ鈤0W ؠ#H4	'Te1sWx.'F%te$L3H}lMUהia$;1kGt_Q3%2YPQ8Qy6\cr<j(O)Wr#0:(2l<Hky$0m_Zm,脥FQiiP˲1ءAT6a W55	I# 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uvq!	#ğ=80U0
+ sB#EiLoP
+1ɡ}l
+]oUv3U^A0|
+|S5qToגkH⸨
+7U1w8ςr/-3Y]5&JՌRҸ^c;2)8\l@7c3"
+C׊4]1ҚRjܸ?5JKz c'1UVG g(/2 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U06ގQ?L S00U0
 	*H
-  }T[ipT!5]]M+P;"͛*q^}w`"8@I1~StV q=NAp-N¼!~v<Uu=狖U~RZ<ڌXGI΄O_#$V*Ar49֐A{=\ݳӏ<,JY)uC(xq0hYg`A]\"Bbeq
-ldʪiG^SI-/C^A~J00}LWc0
+  Y3~}uiA2#y
+־9cEF֩$/lT]mkndSܛ}x*f .}FNkVHmJ$W_WiH:vuŏ袒|Vͅus;LV5yYmYyz0[uB~.f!HA$at(nEMOĽ	v5)5fbI<bC'd+H\ϋ00}LWc0
 	*H
  0b10	UUS10U
 
@@ -165,13 +194,20 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS:0	+ 0	*H
+Apple Inc.10	UUS;^0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251215123701Z0#	*H
-	1cbd.:RoT:0+*H
-	1000Ӟw!\ _0
+260106194149Z0#	*H
+	1a7]Sv~0+*H
+	1000ةHYfG7 0
 	*H
-  eEWYukU$MioV1!qx{r:Mk1oePq:·)`f	gdQ0y9l%Ts)ԝ"_4uywgZ|H/+%Hͨ6p-xPy<+}{0phLdG}-[73Az6Tl9_p\7߽9|]      
\ No newline at end of file
+  1|tP$
+f4̦F.4(o|Hv
+[4grv*獕
+OG]PfޞL=~<؁݇'vhw6hD`aRQYHXl3M@\/b
+`
+ۡ);s~__|
+*=MߟA2Baaog9poc&EGڶ"W,ʞoxѽgbN&
+Ӗ      
\ No newline at end of file
