@@ -1,10 +1,34 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      b      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              z   4                     Gjuliac-trim-stdlib A427R7F42H 4m蹃CUd                    J_N}qb
-\{ǭZ                            juliac-trim-stdlib                    
+    Mac OS X            	   2  *P     *                                      ATTR      *  L  )6                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      	     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Gjuliac-trim-stdlib A427R7F42H !R3~v1                                        4m蹃CUd                    J_N}qb
+\{ǭZqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                            juliac-trim-stdlib                    
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      Gjuliac-trim-stdlib A427R7F42H 9R'
+A427R7F42H               4                      Gjuliac-trim-stdlib A427R7F42H ONvHl_Zt+5b4UEhY2                                                                9R'
 N|4Xaؼ t                                ل#Fm:Oa{w&YѶTc0	*H
 010
 	`He 0	*H
@@ -83,56 +107,52 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251215123700Z0/	*H
-	1" ߿vF`HBjA
-/ZE-݂`0[	*Hcd	1N0+)qD`fTzvw0-	`He .\XSKWj'kI]ܲ9Կ-=ӌ;0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260106194149Z0/	*H
+	1" <:+@gץcЎAʛ0[	*Hcd	1N0+7QDP=d90-	`He y41aֽf0伀c(?wətK0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		tClxkPVEYAtmhbdUod56FXbS9Hc=
+		FZjqyjfHExedURvZ9ERQPRlkOd8=
 		</data>
 		<data>
-		+y5cWNtTS4fZV2rWJ/Wb42sS8kk=
+		l3mJiTQb/eoxkmHK5Na9ZjARu+Q=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  qo daPC>b\80NԻV
-AAlƥ1$ X2R-NXP/uvՓ.鳌j!upN)C|޾nL:'r-C}MMۮ0al%MN|ѫ0_*(ԏj^&vjZܔ&0;σFl]׊wqC1nT0ƿN^=
-N8dePzUIt=ڝ(
-d7-0*H
+  {)8jv
+C:-2U4jnkb,^=F>NuGV.໠֦h^b@T_a3)3Ĕ͔oZJ`gc
+;Ͱ\0i=q&	#;m^:9֏֩;mFyɥ.^~j)NgtDִU"MZ'p`+RYE30*H
 	10	*H
 010	+ 0{*H
 	lj0h*010
-	`He  hJ֛V	48fл'61.bɖ`1:h20251215123700Z0	 ͱU-g:
-00Qw0
+	`He  %LZd~ᜐL_/?IvCײnI20260106194150Z0	 ޢ0L
+00;^0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-251208174023Z
-260119174022Z0A10UTimestamp Signer MA110U
+260105174054Z
+260216174053Z0A10UTimestamp Signer MA210U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- r	%y!nfXaM6#JMi6q`t2ѷ325:Ԫa
-T7\q}# TWNE^_or?/IS %`ZT|J@1Uc-o90hvi8ٖ8^0ı1#!	E|}{h`{c"J
-*mЏ8lpOϿv1
-&@%;?_~y 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U]m#=J.E0U0
+ sB#EiLoP
+1ɡ}l
+]oUv3U^A0|
+|S5qToגkH⸨
+7U1w8ςr/-3Y]5&JՌRҸ^c;2)8\l@7c3"
+C׊4]1ҚRjܸ?5JKz c'1UVG g(/2 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0U06ގQ?L S00U0
 	*H
-  (v^!뎥htZl3/u[g8ϋvą)Ӈ<g dPf?~_'+(~T9SȘq*I!/H!b9	r&v:#BڳlXg;
-Q5@q4icQG7}ȺS*N5
-L-^Dp
-"!OwH:YkrL
-GX;,]^@F*i
-:5-⥍t,\O100}LWc0
+  Y3~}uiA2#y
+־9cEF֩$/lT]mkndSܛ}x*f .}FNkVHmJ$W_WiH:vuŏ袒|Vͅus;LV5yYmYyz0[uB~.f!HA$at(nEMOĽ	v5)5fbI<bC'd+H\ϋ00}LWc0
 	*H
  0b10	UUS10U
 
@@ -173,17 +193,14 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUSQw0	+ 0	*H
+Apple Inc.10	UUS;^0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251215123700Z0#	*H
-	1qI\؈=ߙ$7dK0+*H
-	1000A=aHKԳZ(0
+260106194150Z0#	*H
+	16̳hGpPDdy0+*H
+	1000ةHYfG7 0
 	*H
-  vg=,"{0u,ps.qC؛=΁ܮ\~lD.N?S!v]ii$	gR,m~{DfxVCSߐarL$.1Y0
-#	Tɳs1/
-nEs_
-QORR\wK']G@CqXKv[I}T|mVw;z%:k
- LD~      
\ No newline at end of file
+  R8jv)RDY.g`8įV
+8\+4!7Xa=(+(! .VGAG&V.5Pkz64ʯlD9Quە8PѠ\mu=~re"sa/PB.P)Au>C0gD΀[D[ġqp#j?eDeAC/J^UW?l exYi	n12      
\ No newline at end of file
