@@ -1,9 +1,34 @@
-    Mac OS X            	   2  &{     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements      Q      com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature              q   4                     >generator A427R7F42H y*-#q0                    MKxӧ!ax                            	generator                     
+    Mac OS X            	   2  *5     *g                                      ATTR      *g  L  )                 L     com.apple.cs.CodeDirectory     
+    com.apple.cs.CodeEntitlements            com.apple.cs.CodeRequirements        	   com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     >generator A427R7F42H !R3~v1                                        y*-#q0                    MKxӧ!axqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                            	generator                     
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      >generator A427R7F42H z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
+A427R7F42H    	           4                      >generator A427R7F42H ONvHl_Zt+5b4UEhY2                                                                z|R!A$п44!+*6̊)                                SdL\0Fh]0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -81,55 +106,51 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251215123700Z0/	*H
-	1" ױP~Oףؠ
-0[	*Hcd	1N0+ajO${fQP0-	`He 0 3ݴ<l,#_?_{10[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260106194150Z0/	*H
+	1" ҫH(iͱVps59t40[	*Hcd	1N0+ℶץw8&ZeXw10-	`He sX@KƒtK3A)Y/Jу0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		oQvb7WHf7mr4TyR7if64ZlFQj7I=
+		8gfihLbXpXcZBTjNJlpl3Fh3AjE=
 		</data>
 		<data>
-		MAAzrt20sAY8bCyKGSOS+BdfPwY=
+		q3Oh8ljg+Q5AS8aS/3RLM58eBEE=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  Mzb+:وGFޡ
-̋6̥۶1zMƔE8n İRѲ#)#Y#;/C@^MVK']n01͌O8XePe#.;lC01ewd\JFŝux;c63Pj#1
-\`ܩ'iy-rv<,i~h^gGK []yt'޺EHn(h؞͉8ZyU0*H
+  HNiR>ăGEEuvU Gױtk^ <βX86;aw4MFpY?&F`1|։b`W,7EWU>9p+d+M3PA'lmV`g
+@C
+'dh-m
+/2L`Z\T@.Ð	VeٽwUXRAR.&r~T'RdYm:,bhU6\tL*$ mFE+NT0*H
 	10	*H
-010	+ 0{*H
-	lj0h*010
-	`He  2%O4QrUQ'--T8*20251215123701Z0	 hQl=D
-00Qw0
+010	+ 0z*H
+	ki0g*010
+	`He  H91Swҝ^s*IiО,K:	m ٣*20260106194151Z0^v+ i
+00{E0Q;0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-251208174023Z
-260119174022Z0A10UTimestamp Signer MA110U
+260105174054Z
+260216174053Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- r	%y!nfXaM6#JMi6q`t2ѷ325:Ԫa
-T7\q}# TWNE^_or?/IS %`ZT|J@1Uc-o90hvi8ٖ8^0ı1#!	E|}{h`{c"J
-*mЏ8lpOϿv1
-&@%;?_~y 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0U]m#=J.E0U0
+ t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
+PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
+ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
 	*H
-  (v^!뎥htZl3/u[g8ϋvą)Ӈ<g dPf?~_'+(~T9SȘq*I!/H!b9	r&v:#BڳlXg;
-Q5@q4icQG7}ȺS*N5
-L-^Dp
-"!OwH:YkrL
-GX;,]^@F*i
-:5-⥍t,\O100}LWc0
+  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
+>G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
+މASVO@C]>{6%@nm|?A"00}LWc0
 	*H
  0b10	UUS10U
 
@@ -170,16 +191,17 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUSQw0	+ 0	*H
+Apple Inc.10	UUS{E0Q;0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251215123701Z0#	*H
-	1O_ڝi?v0
-30+*H
-	1000A=aHKԳZ(0
+260106194151Z0#	*H
+	1V(_:?{Z
+s/00+*H
+	10004,yz9_0
 	*H
-  wKkֱLi O+]и<ES[7=
-)iK[cznUM=`{%eJ7Yp"
-UêQRX$5^lq?pӹe3ٌH7iw?QtJ+.fM{+ΫtAZpz5<M@6X2l;܇|~$3^	RDst+t>(ELgf̨ve	q      
\ No newline at end of file
+  SrOLWM(EJd򔡷LUFM1ܥuĺ
+m~$
+ўWVVs^L+f	7`'˔%tqEM
+1Ȩwe6``DRMc_#[tEXy0RaJ0;ћ;nݫ&hIݠʊ39&G$~J8"]Fɻ5{X5(W *@Dp+      
\ No newline at end of file
