@@ -1,10 +1,35 @@
-    Mac OS X            	   2  &     &                                      ATTR      &     %                       com.apple.cs.CodeDirectory          com.apple.cs.CodeRequirements            com.apple.cs.CodeRequirements-1    J  #  com.apple.cs.CodeSignature              {   4                     Hmake-fancy-terminfo A427R7F42H s'CwTv                    /sEk                  H    ,            
+    Mac OS X            	   2  *     *                                      ATTR      *  L  )l                 L     com.apple.cs.CodeDirectory         com.apple.cs.CodeEntitlements      
+     com.apple.cs.CodeRequirements           com.apple.cs.CodeRequirements-1      #  com.apple.cs.CodeSignature                 4                     Hmake-fancy-terminfo A427R7F42H !R3~v1                                        s'CwTv                    /sEkqq  <?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+	<key>com.apple.security.get-task-allow</key>
+	<true/>
+	<key>com.apple.security.cs.allow-dyld-environment-variables</key>
+	<true/>
+	<key>com.apple.security.cs.allow-jit</key>
+	<true/>
+	<key>com.apple.security.cs.allow-unsigned-executable-memory</key>
+	<true/>
+	<key>com.apple.security.cs.debugger</key>
+	<true/>
+	<key>com.apple.security.cs.disable-library-validation</key>
+	<true/>
+	<key>com.apple.security.device.audio-input</key>
+	<true/>
+	<key>com.apple.security.device.camera</key>
+	<true/>
+</dict>
+</plist>
+                  H    ,            
 com.apple.env                      make-fancy-terminfo                   
 *Hcd                   
 *Hcd
                 
 subject.OU        
-A427R7F42H                4                      Hmake-fancy-terminfo A427R7F42H 5+>ӤY7vm,-y                                 ݆TVTNrqnXzbĀ0	*H
+A427R7F42H               4                      Hmake-fancy-terminfo A427R7F42H ONvHl_Zt+5b4UEhY2                                                                5+>ӤY7vm,-y                                 ݆TVTNrqnXzbĀ0	*H
 010
 	`He 0	*H
   0>0& ?͗Iz˃Mxs]C0
@@ -82,48 +107,54 @@ Apple Inc.10	UUS!u	LrZ=0
 	1	*H
 0	*H
 	1
-251215123700Z0/	*H
-	1" {cWJjɮWhAF>Dv*	0[	*Hcd	1N0+q7Z.7|0-	`He "%i7%pp+dF
-&/j#vFK0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
+260106194149Z0/	*H
+	1" I08li|H<x^[zߡp7HYKu0[	*Hcd	1N0+
+1yrzi\DT0-	`He ߥPdR.)7\1Kj/N4=0[	*Hcd	1LH<?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
 <plist version="1.0">
 <dict>
 	<key>cdhashes</key>
 	<array>
 		<data>
-		nHGbDoXNHDdanfW2i6guN/wfBHw=
+		CjF5Dh9yj3qc5Glcp+MIRFTil/I=
 		</data>
 		<data>
-		rCIlaTclcHArmWQGHBpGDSbIL/s=
+		36VQZPxS56XOfy4pNxDTXDFLai8=
 		</data>
 	</array>
 </dict>
 </plist>
 0
 	*H
-  `r]W x1A#'Tb98x]bE=|n񈹃	ظ[f8gS(|N2(+=CIO]B 
-;Bz^'8"Ċ03|/zZi /@<c>夎8=/HzʺAS7s>nzW?a{71!'I)sޘP6\%~Aف$kHNKG,35`0*H
+  a'.ƅ[0QH)pb=s8ԵSSJV鳠he,\  z0xǠK<u]xg
+dehTSl?|<S_T,XAvBc|Yۧ8.ǱTlm^JkR
+VZaܛ}#,ރ3#l0؅G>#j:e$L
+؊ۂ[q@` vʎq%=VS0*H
 	10	*H
-010	+ 0z*H
-	ki0g*010
-	`He  m ?RUT@F7H.5
-X0h20251215123701Z0dRe󈠂
-00:0
+010	+ 0{*H
+	lj0h*010
+	`He  vgFZ=3"
+h^*ڱv
+iB4-20260106194150Z0	 5ڠ
+00{E0Q;0
 	*H
  0|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
 Apple Inc.10	UUS0
-251208174023Z
-260119174022Z0A10UTimestamp Signer MA210U
+260105174054Z
+260216174053Z0A10UTimestamp Signer MA110U
 
 Apple Inc.10	UUS0"0
 	*H
   0
- PT3HʦY$)4 ꩦ鈤0W ؠ#H4	'Te1sWx.'F%te$L3H}lMUהia$;1kGt_Q3%2YPQ8Qy6\cr<j(O)Wr#0:(2l<Hky$0m_Zm,脥FQiiP˲1ءAT6a W55	I# 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
-+03U,0*0(&$"http://crl.apple.com/timestamp.crl0Uvq!	#ğ=80U0
+ t]o5O(㦣l^F`tQ<GH#Si\qz/ $.H^=3H.Cz[I9;4%
+PF5tld}} gX7	WӖ=o=Br#s^^ψ!zl|j 
+ӡi	XmHj "ߝDm1汼)k1	"@{ φ2;+\R\VeA 00U0 0U#04%N78X&)0U 00	*Hcd00(+http://www.apple.com/appleca0+0Reliance on this certificate by any party assumes acceptance of the then applicable standard terms and conditions of use, certificate policy and certification practice statements.0U%0
++03U,0*0(&$"http://crl.apple.com/timestamp.crl0UGZ(cVynw.0U0
 	*H
-  }T[ipT!5]]M+P;"͛*q^}w`"8@I1~StV q=NAp-N¼!~v<Uu=狖U~RZ<ڌXGI΄O_#$V*Ar49֐A{=\ݳӏ<,JY)uC(xq0hYg`A]\"Bbeq
-ldʪiG^SI-/C^A~J00}LWc0
+  ?֤1R?ǫ .udi9Vg\]{P?\h}pAcy
+>G%̇3HK iXA˾s)rCJ56!x*O#G+0K	dK$MnרO?@Ŧ'hBޭ
+މASVO@C]>{6%@nm|?A"00}LWc0
 	*H
  0b10	UUS10U
 
@@ -164,16 +195,17 @@ bqGSU/ApLE~LkPAtbA30XZ2hesg^eIv3ew- z0v0U0U0
 k+Y	|@Vtӷ#;Go$ѷpE'mx~"5%kԢ$#s`[	/DH`8=&g 3j
 /Sj[dc3w:,V!ںsO6U٧2Bq~RB$*M^cKP	7uu!1?0;00|100.U'Apple Timestamp Certification Authority1&0$UApple Certification Authority10U
 
-Apple Inc.10	UUS:0	+ 0	*H
+Apple Inc.10	UUS{E0Q;0	+ 0	*H
 	1
 *H
 	0	*H
 	1
-251215123701Z0#	*H
-	1E'pҘ+W
-ڀ`Y90+*H
-	1000Ӟw!\ _0
+260106194150Z0#	*H
+	1<֩8^eE:[j0+*H
+	10004,yz9_0
 	*H
-  ~b+8n/!o&f8}-bNvؘêuoEIUТ=CčݢxN@ybt4(. Y\cت ~)|
-U?堛1)`i"
-c;SHEs'^( ;&/bE/D !h;toVc=]aM7~/FE0x4dD#Wru_=wN'-&QFfT}&      
\ No newline at end of file
+  Ju!LzL:Ee-4W`jAA&ݪ
+h\UJJMϦ@j=Kekc5QRU %/xa͝>$GZΈKiikbxM0,%S8k΀l#wZteIN³	`&TT'0I\
+9r{`u/V3"[[
+KDÕIWDQ.gʌ
+Q{랾1aF9      
\ No newline at end of file
